@@ -184,7 +184,7 @@ def extract_grouped_data(data: str, key: str) -> str:
     grouped_data = reduce(lambda prev, curr: {
         **prev,
         **{curr.split(':')[0]: curr.split(':')[1]}
-    }, data.split(';'), {}) if data is not None and len(data) > 1 else {}
+    }, data.split(';'), {}) if data is not None and isinstance(data, str) and len(data) > 1 else {}
     return grouped_data.get(key)
 
 
@@ -215,7 +215,7 @@ def extract_grouped_data_closest_date(data: str, year: int) -> str:
         } if len(curr) > 0 and curr.split(':')[1] != '-' else prev,
         data.split(';'),
         {}
-    ) if data is not None and len(data) > 1 else {}
+    ) if data is not None and isinstance(data, str) and len(data) > 1 else {}
     dist_years = list(data_by_date.keys())
     closest_year = min(dist_years, key=lambda x: abs(int(x) - year)) if len(dist_years) > 0 else None
     return None if closest_year is None else data_by_date.get(closest_year)
